from quart import Quart, make_response, jsonify
from quart_schema import QuartSchema, RequestSchemaValidationError

from .blueprints import users_blueprint
from .exceptions import ExpectedError

app = Quart(__name__)
QuartSchema(app)

app.register_blueprint(users_blueprint)

for route in app.url_map.iter_rules():
    print(route, route.host)


@app.errorhandler(RequestSchemaValidationError)
async def handle_request_validation_error(error: RequestSchemaValidationError):
    print(error.validation_error)
    return {"error": "VALIDATION"}, 400


@app.errorhandler(ExpectedError)
async def handle_expected_error(error: ExpectedError):
    return {"code": error.type, "message": error.msg}, error.status_code
