from sqlalchemy.ext.asyncio import AsyncSession
from sqlalchemy import select
from quart import g

from .user import User
from foxnouns.exceptions import ForbiddenError


async def user_from_ref(session: AsyncSession, user_ref: str):
    """Returns a user from a `user_ref` value. If `user_ref` is `@me`, returns the current user.
    Otherwise, tries to convert the user to a snowflake ID and queries that. Otherwise, returns a user with that username.
    """
    query = select(User)

    if user_ref == "@me":
        if "user" in g:
            query = query.where(User.id == g.user.id)
        else:
            raise ForbiddenError("Not authenticated")
    else:
        try:
            id = int(user_ref)
            query = query.where(User.id == id)
        except ValueError:
            query = query.where(User.username == user_ref)

    return await session.scalar(query)
